@@ -128,4 +128,5 @@ PSTALLRXMON = "CFG-MSG - Turn ON all RXM msgs"
 PSTALLRXMOFF = "CFG-MSG - Turn OFF all RXM msgs"
 PSTPOLLPORT = "CFG-PRT - Poll Port config"
 PSTPOLLINFO = "CFG-INF - Poll Info message config"
-PSTPOLLALL = "CFG-xxx - Poll Everything Available"
+PSTPOLLALLCFG = "CFG-xxx - Poll All Configuration Messages"
+PSTPOLLALLNAV = "NAV(2)-xxx - Poll All Navigation Messages"
