@@ -50,6 +50,7 @@ UBX_CONFIG_CATEGORIES = [
     "CFG_BDS",
     "CFG_GEOFENCE",
     "CFG_HW_ANT",
+    "CFG_HW_RF",
     "CFG_I2C",
     "CFG_INFMSG",
     "CFG_ITFM",
@@ -76,6 +77,7 @@ UBX_CONFIG_CATEGORIES = [
     "CFG_SFIMU",
     "CFG_SFODO",
     "CFG_SIGNAL",
+    "CFG_SPARTN",
     "CFG_SPI",
     "CFG_TMODE",
     "CFG_TP",
