@@ -5,7 +5,9 @@ Created on 22 Dec 2020
 
 Created on 22 Sep 2020
 
-@author: semuadmin
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: BSD 3-Clause
 """
 # pylint: disable=invalid-name, too-many-instance-attributes, too-many-ancestors
 
@@ -53,8 +55,10 @@ class UBX_MSGRATE_Frame(Frame):
         """
         Constructor.
 
-        :param object app: reference to main tkinter application
-        :param frame container: container frame
+        :param Frame app: reference to main tkinter application
+        :param Frame container: reference to container frame (config-dialog)
+        :param args: optional args to pass to Frame parent class
+        :param kwargs: optional kwargs to pass to Frame parent class
         """
 
         self.__app = app  # Reference to main application class
@@ -76,7 +80,7 @@ class UBX_MSGRATE_Frame(Frame):
         self._body()
         self._do_layout()
         self._attach_events()
-        self._reset()
+        self.reset()
 
     def _body(self):
         """
@@ -186,7 +190,7 @@ class UBX_MSGRATE_Frame(Frame):
 
         self._lbx_cfg_msg.bind("<<ListboxSelect>>", self._on_select_cfg_msg)
 
-    def _reset(self):
+    def reset(self):
         """
         Reset settings to defaults.
         """
@@ -200,6 +204,9 @@ class UBX_MSGRATE_Frame(Frame):
     def update_status(self, cfgtype, **kwargs):
         """
         Update pending confirmation status.
+
+        :param str cfgtype: identity of UBX message containing config info
+        :param kwargs: status keywords and values from UBX config message
         """
 
         if cfgtype == "CFG-MSG":
